@@ -185,7 +185,7 @@ local function get_element_bb_if_visible(element, wbb, page)
     -- Find the element bounding box
     local r
 
-    if has_client_rects_api then
+    if has_client_rects_api and not element.first_child then
         r = element:client_rects()
         for i=#r,1,-1 do
             if r[i].width == 0 or r[i].height == 0 then table.remove(r, i) end
@@ -283,8 +283,11 @@ local function frame_find_hints(page, frame, elements)
         local rbb = get_element_bb_if_visible(element,wbb, page)
 
         if rbb then
-            local text = element.text_content
-            if text == "" then text = element.value or "" end
+            local text = ""
+            if element.type ~= "password" then
+                text = element.text_content
+                if text == "" then text = element.value or "" end
+            end
             if text == "" then text = element.attr.placeholder or "" end
             hints[#hints+1] = { elem = element, bb = rbb, text = text }
         end
